@@ -1,7 +1,7 @@
 from ._victor_common import _VictorCommon
 from ..monster import Monster
 from ..igor import Igor
-from ..m_rmsd import mRSMD
+from ..m_rmsd import mRMSD
 from typing import List, Optional, Dict, Union, Callable
 from rdkit import Chem
 from rdkit.Chem import AllChem
@@ -113,7 +113,7 @@ class _VictorCombine(_VictorCommon):
         # self.params.CHI.data = []  # TODO check if chi fix is okay
         self._log_warnings()
         self.post_params_step()  # empty overridable
-        self.mmerging_mode = 'full'
+        self.mmerging_mode = 'full' #TODO: check if this is intended
         self.unminimized_pdbblock = self._plonk_monster_in_structure()
         params_file, holo_file, constraint_file = self._save_prerequisites()
         self.unbound_pose = self.params.test()
