@@ -1,3 +1,4 @@
+from __future__ import annotations
 ########################################################################################################################
 
 __doc__ = \
@@ -27,7 +28,7 @@ from rdkit import Chem
 from rdkit.Chem import rdFMCS, AllChem
 
 from ._victor_common import _VictorCommon
-from ..m_rmsd import mRSMD
+from ..m_rmsd import mRMSD
 from ..monster import Monster
 from rdkit_to_params import Params
 from ..igor import Igor
@@ -455,7 +456,7 @@ class _VictorUtils(_VictorCommon):
     # =================== From Files ===================================================================================
 
     @classmethod
-    def from_files(cls, folder: str) -> 'self':
+    def from_files(cls, folder: str) -> _VictorUtils:  # future.annotation is active, so no cyclical.
         """
         This creates an instance form the output files. Likely to be unstable.
         Assumes the checkpoints were not altered.
@@ -528,7 +529,7 @@ class _VictorUtils(_VictorCommon):
         # buffers etc.
         self._warned = []
         minjson = os.path.join(folder, f'{self.long_name}.minimised.json')
-        self.mrmsd = mRSMD.mock()
+        self.mrmsd = mRMSD.mock()
         if os.path.exists(minjson):
             md = json.load(open(minjson))
             self.energy_score = md["Energy"]
